package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````@)D$"#0```#LQ0```````#0`(``)
M`"@`)``A``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(5+``
M`%2P```%`````!````$```#DO@``Y$X%".1.!0AT`@``P!(```8`````$```
M`@```/B^``#X3@4(^$X%"/@```#X````!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%'E=&0```````````````````````````8`
M```$````4N5T9.2^``#D3@4(Y$X%"!P!```<`0``!`````$```"`%01E````
M````````````````````````*```!````"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@````P````$````%`````,```!'
M3E4`@V;"1[88]`A,L2_:\LZ%H*+T9L4E````3@````@````(`````!`0!"5`
M!("H$0`!HH9!J$````)+*`0I.*(R1XH$#(A.````4```````````````````
M`%,```!5````5@````````!7````6`````````!9````6@```%L`````````
M7````````````````````%T```!@``````````````!A````8P```&0```!F
M`````````&@```!K`````````&T```!N````;P```'``````````R-6R<5GH
M[>SF_S"BSMY'+:/@^TGJT^\.I]VC:R_%F[;;S>.>A_F<@6L)0]8-.I<+Q8D%
MD`T4XIXA_^0.L@&+;\2YG$!K?YI\?ZF<FV[%WQ_9<5@<N^.2?-1DU'RM2^/`
M,F+;[>&G`@IFK\QF8!;)67OP2FOB1\8!0T75[$?L,SI]08[%P^4_+/+;TQWZ
MH6Q@N8WQ#@`````````````````````!`P`````````````2````2`,`````
M````````$@```+,``````````````!(```"6`P`````````````2````@0,`
M````````````$@```*,!`````````````!(```!\`@`````````````2````
M$P``````````````(````"(``````````````"````"'`P`````````````2
M````CP$`````````````$@```#8$`````````````!(```!P`0``````````
M```2````@@$`````````````$@```&$#`````````````!(````Q`P``````
M```````2````X`(`````````````$@```"X"`````````````!(```#_````
M```````````2````'@(`````````````$@```+(#`````````````!(```#,
M`0`````````````2````&@0`````````````$@```.T"`````````````!(`
M``#H`@`````````````2````F@(`````````````$@```.P!````````````
M`!(```"H`0`````````````2````-P(`````````````$@```$`$````````
M`````!(````,!``````````````2````,0$`````````````$@```,T#````
M`````````!(````V```````````````2````U0,`````````````$@```%\!
M`````````````!(```#*```````````````2````^@,`````````````$@``
M`,8#`````````````!(```#S`P`````````````2````JP,`````````````
M$@```'H#`````````````!(````U!0`````````````2````0P$`````````
M````$@```.,#`````````````!(```!>`@`````````````2````6`,`````
M````````$@```!(#`````````````!(```!0`@`````````````2````N0,`
M````````````$@```),"`````````````!(```"M`0`````````````2````
M:0,`````````````$@```,`#`````````````!(```"D`P`````````````2
M````[@``````````````$@```$0``````````````!(```#J`P``````````
M```2````!`0`````````````$@```-D``````````````!(``````@``````
M```````2````AP(`````````````$@```%(!`````````````!(```"/`P``
M```````````2````4`,`````````````$@```-D"`````````````!(````?
M`0`````````````2````10(`````````````$@```%8``````````````!(`
M``"=`P`````````````2````V@$`````````````$@```&4`````````````
M`!(````3!``````````````2````D0``````````````$@```$,#````````
M`````!(```!Z```````````````2````#0$`````````````$@```+D!````
ME00(`````!(```#6!````-0$"`0````1``\`GP4``.#6!`AN60``$0`/`*D%
M``!EO@0(U`<``!(`#0#5!0``8:,$"-$!```2``T`T`0``.33!`@`````$@`.
M`"X$``!@404(!````"$`&`"H!```79\$"`T````2``T`;@4``/S2!`A?````
M$@`-`*(```#0E@0(`````!(```!9!0``/%$%"``````0`!<`6P4``#Q1!0@`
M````(``7`"T$``!@404(!````"$`&`#&!```6],$"`$````2``T`R`4``&J?
M!`BT`@``$@`-`/,$```RI00(40```!(`#0`L!```8%$%"`0````1`!@`)P0`
M``K0!`BO`@``$@`-`",%``!#O`0(-P```!(`#0`^!0``G\<$"&`````2``T`
M8`0``%A1!0@`````$`#Q_VP$``"D804(`````!``\?_=!```DLH$"`P%```2
M``T`(@,```34!`@$````$0`/`%\%``"`F00(`````!(`#0`!!0``5YX$"`8!
M```2``T`%P4``&"B!`@!`0``$@`-`$H%``!4404(!````!$`%P!L`@``P)8$
M"``````2````N00``!ZB!`A"````$@`-`%D$``!8404(`````!``\?^:!0``
M4%$%"`0````1`!<`?@4``#;*!`A<````$@`-`&8%```8F@0(1````!(`#0"E
M`@``9%$%"!,````1`!@`M@4``#"]!`@U`0``$@`-`&@%``!0E`0(`````!(`
M"P``;&EB<&5R;"YS;RXU+C$R+C``7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES
M=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?27-T871B=69?<'1R`%!E
M<FQ?<WES7VEN:70S`%!E<FQ?265X:71?9FQA9W-?<'1R`%!E<FQ?<V%V95]D
M97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T<@!097)L7V%T9F]R:U]L;V-K
M`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R;%]C;VYS=')U8W0`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R7W!T<@!097)L7V%V7W-H:69T
M`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O<%]E;G9?<'1R`%!E<FQ?271A
M:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?;F5W4U9P=@!097)L7VYE
M=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R`%!E<FQ?26]P7W!T<@!097)L
M7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T
M9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7T=T:')?:V5Y7W!T<@!0
M97)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?
M<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T
M:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T<W!E
M8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T
M9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S<')I;G1F`'-T<FYC
M;7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M
M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L
M96X`;65M<V5T`'-T<G-T<@!R;61I<@!M96UC<'D`;W!E;F1I<@!?7V-T>7!E
M7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E>&5C=G``<F5A9&1I<C8T`&UE;6UO
M=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`
M7U]X<W1A=#8T`%]?;'AS=&%T-C0`;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B
M<W-?<W1A<G0`7V5N9``O=7-R+VQI8B]P97)L-2\U+C$R+C`O:38X-BUP;&0M
M;&EN=7@M=&AR96%D+6UU;'1I+T-/4D4`<&%R7V-U<G)E;G1?97AE8P!P87)?
M8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%]F<%]H=P!84U]);G1E<FYA;'-?
M4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``<VEZ95]L;V%D7VUE7S(`7U]D871A7W-T87)T`'AS7VEN:70`7U]L
M:6)C7V-S=5]I;FET`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!N86UE
M7VQO861?;65?,@!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7V9I;F1P<F]G`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1TQ)0D-?,BXS`$=,
M24)#7S(N,RXR`$=,24)#7S(N,@!'3$E"0U\R+C`````"``,````#``,`````
M```````#````!````````P`%``8``````````P````,``@`"```````#````
M!``#`````P````<```````0``P`#``,``P`#`````P````,``@````,``P``
M``@``P`#```````#``,````````````#``,`!@`````````#```````#````
M`P`````````!``$``0`!``$``P`!``$````!``$``P`!``$``0`#``$``0`!
M``$``0`!``$``0`!``$``0````$``0`!``$``0````$``0`!``4`&`,``!``
M``!@````%&EI#0``"`#B!0``$````!-I:0T```<`[`4``!````!R&6D)```%
M`/8%```0````$FEI#0``!``"!@``$````!!I:0T```,`#`8````````!``(`
MR0(``!``````````$FEI#0``!@`"!@``$````!!I:0T```(`#`8```````#P
M3P4(!@@``&!1!0@%7@``9%$%"`5P````4`4(!P$```10!0@'`@``"%`%"`<#
M```,4`4(!P0``!!0!0@'!0``%%`%"`<&```84`4(!P<``!Q0!0@'3@``(%`%
M"`<(```D4`4(!PH``"A0!0@'"P``+%`%"`<,```P4`4(!PT``#10!0@'#@``
M.%`%"`</```\4`4(!Q```$!0!0@'$0``1%`%"`<2``!(4`4(!Q,``$Q0!0@'
M%```4%`%"`<5``!44`4(!Q8``%A0!0@'%P``7%`%"`<8``!@4`4(!QD``&10
M!0@'&@``:%`%"`<;``!L4`4(!QP``'!0!0@''0``=%`%"`<>``!X4`4(!Q\`
M`'Q0!0@'(```@%`%"`<A``"$4`4(!R(``(A0!0@'(P``C%`%"`=J``"04`4(
M!U<``)10!0@')```F%`%"`<E``"<4`4(!R8``*!0!0@')P``I%`%"`<H``"H
M4`4(!RD``*Q0!0@'*@``L%`%"`<K``"T4`4(!RP``+A0!0@'+0``O%`%"`<N
M``#`4`4(!R\``,10!0@',```R%`%"`<Q``#,4`4(!S(``-!0!0@',P``U%`%
M"`<T``#84`4(!S4``-Q0!0@'-@``X%`%"`<W``#D4`4(!S@``.A0!0@'.0``
M[%`%"`<Z``#P4`4(!SL``/10!0@'/```^%`%"`<]``#\4`4(!SX```!1!0@'
M/P``!%$%"`=````(404(!T$```Q1!0@'0@``$%$%"`=#```4404(!T0``!A1
M!0@'10``'%$%"`=&```@404(!T<``"11!0@'2```*%$%"`=)```L404(!TH`
M`#!1!0@'2P``-%$%"`=,```X404(!TT``%6)Y5.#[`3H`````%N!PYB[``"+
MD_S___^%TG0%Z)X```#H?`4``.A`/P``6%O)P_\U^$\%"/\E_$\%"`````#_
M)0!0!0AH`````.G@_____R4$4`4(:`@```#IT/____\E"%`%"&@0````Z<#_
M____)0Q0!0AH&````.FP_____R404`4(:"````#IH/____\E%%`%"&@H````
MZ9#_____)1A0!0AH,````.F`_____R4<4`4(:#@```#I</____\E(%`%"&A`
M````Z6#_____)210!0AH2````.E0_____R4H4`4(:%````#I0/____\E+%`%
M"&A8````Z3#_____)3!0!0AH8````.D@_____R4T4`4(:&@```#I$/____\E
M.%`%"&AP````Z0#_____)3Q0!0AH>````.GP_O___R5`4`4(:(````#IX/[_
M__\E1%`%"&B(````Z=#^____)4A0!0AHD````.G`_O___R5,4`4(:)@```#I
ML/[___\E4%`%"&B@````Z:#^____)510!0AHJ````.F0_O___R584`4(:+``
M``#I@/[___\E7%`%"&BX````Z7#^____)6!0!0AHP````.E@_O___R5D4`4(
M:,@```#I4/[___\E:%`%"&C0````Z4#^____)6Q0!0AHV````.DP_O___R5P
M4`4(:.````#I(/[___\E=%`%"&CH````Z1#^____)7A0!0AH\````.D`_O__
M_R5\4`4(:/@```#I\/W___\E@%`%"&@``0``Z>#]____)810!0AH"`$``.G0
M_?___R6(4`4(:!`!``#IP/W___\EC%`%"&@8`0``Z;#]____)9!0!0AH(`$`
M`.F@_?___R644`4(:"@!``#ID/W___\EF%`%"&@P`0``Z8#]____)9Q0!0AH
M.`$``.EP_?___R6@4`4(:$`!``#I8/W___\EI%`%"&A(`0``Z5#]____):A0
M!0AH4`$``.E`_?___R6L4`4(:%@!``#I,/W___\EL%`%"&A@`0``Z2#]____
M);10!0AH:`$``.D0_?___R6X4`4(:'`!``#I`/W___\EO%`%"&AX`0``Z?#\
M____)<!0!0AH@`$``.G@_/___R7$4`4(:(@!``#IT/S___\ER%`%"&B0`0``
MZ<#\____)<Q0!0AHF`$``.FP_/___R704`4(:*`!``#IH/S___\EU%`%"&BH
M`0``Z9#\____)=A0!0AHL`$``.F`_/___R7<4`4(:+@!``#I</S___\EX%`%
M"&C``0``Z6#\____)>10!0AHR`$``.E0_/___R7H4`4(:-`!``#I0/S___\E
M[%`%"&C8`0``Z3#\____)?!0!0AHX`$``.D@_/___R7T4`4(:.@!``#I$/S_
M__\E^%`%"&CP`0``Z0#\____)?Q0!0AH^`$``.GP^____R4`404(:``"``#I
MX/O___\E!%$%"&@(`@``Z=#[____)0A1!0AH$`(``.G`^____R4,404(:!@"
M``#IL/O___\E$%$%"&@@`@``Z:#[____)111!0AH*`(``.F0^____R48404(
M:#`"``#I@/O___\E'%$%"&@X`@``Z7#[____)2!1!0AH0`(``.E@^____R4D
M404(:$@"``#I4/O___\E*%$%"&A0`@``Z4#[____)2Q1!0AH6`(``.DP^___
M_R4P404(:&`"``#I(/O___\E-%$%"&AH`@``Z1#[____)3A1!0AH<`(``.D`
M^___,>U>B>&#Y/!05%)H6],$"&C\T@0(459H"M`$".A/_/__])"058GE4X/L
M!(`]>%$%"`!U.:%\404(N_!.!0B!Z^Q.!0C!^P*#ZP$YV',8@\`!HWQ1!0C_
M%(7L3@4(H7Q1!0@YV'+HQ@5X404(`8/$!%M=PU6)Y8/L&*'T3@4(A<!T$K@`
M````A<!T"<<$)/1.!0C_T,G#D)!5B>6#["C'1?0(U`0(QP0D`````.C?_O__
MBP")!"3HQ?O__XM5](E4)`S'1"0(P)8$",=$)`02U`0(B00DZ(;^___)PU6)
MY5.![#00``"+10R)A>3O__^+11")A>#O__]EH10```")1?0QP+@NU`0(QT0D
M"/\/``"-E?3O__^)5"0$B00DZ)[]__^)A?#O__^#O?#O__\`?AR+A?#O__^#
MZ`$/MH0%].___X3`=0>#K?#O__\!@[WP[___`'YBBX7P[___B40D",=$)`0O
M````C87T[___B00DZ*K]__^%P'0^BYWP[___QP0D`````.@$_O__BP")!"3H
MZOK__XE<)`R-E?3O__^)5"0(BY7D[___B50D!(D$).@J_/__ZS+'!"0`````
MZ,S]__^+`(D$).BR^O__BY7@[___B50D"(N5Y.___XE4)`2)!"3H=OK__XM%
M]&4S!10```!T!>AU_/__@<0T$```6UW#58GE5U93@^PLBWT(A?]T":%@404(
MA<!U![@`````ZWR)^^L#@\,!#[8#A,!T!P^V`SP]=>^)VHGXB=$IP8E-Y(LU
M8%$%".M)BT7DB40D"(E\)`2)'"3HT?S__X7`=2^+1>2-!`,/M@`\/74BB?*A
M8%$%"(G1*<&)R,'X`HG"BT4,B1"+1>2#P`&-!`/K#H/&!(L>A=MUL;@`````
M@\0L6UY?7<-5B>6#["B-1?2)1"0$BT4(B00DZ$3____)PU6)Y5=64X/L+(MU
M#`^V!CP]=0.#Q@&)-"3HT/K__XE%Y(U%X(E$)`2+10B)!"3H#____XG#A=MT
M,XD<).BM^O__.T7D#X+;````D`^V!H@##[8#A,`/E<"#PP&#Q@&$P'7IN```
M``#I6P$``(L=8%$%"+\`````ZP:#PP2#QP&+`X7`=?2AH&$%"(7`=#&-1P+!
MX`*)PJ%@404(B50D!(D$).@W^/__HV!1!0BA8%$%"(7`=5:X_____^D(`0``
MQP6@804(`0```(U'`L'@`HD$).BW^O__B<.%VW4*N/_____IX````(GXC12%
M`````*%@404(B50D"(E$)`2)'"3H"?O__XD=8%$%"*%@404(B?J#P@'!X@(!
MT,<``````(GXB47@BUT(ZP.#PP$/M@.$P'0'#[8#/#UU[Z%@404(BU7@P>("
MC3P0B=J+10B)T2G!B<@#1>2#P`*)!"3H+/K__XD'BP>%P'4'N/_____K5J%@
M404(BU7@P>("`="+&.L#@\,!BT4(#[8`B`,/M@.$P`^5P(-%"`&$P'0'#[8#
M/#UUWL8#/8/#`9`/M@:(`P^V`X3`#Y7`@\,!@\8!A,!UZ;@`````@\0L6UY?
M7<-5B>53@^PDZR&A8%$%"(M5],'B`HT<$(U#!(L`B0.+`X7`=`6#PP3K[I"-
M1?2)1"0$BT4(B00DZ#?]__^%P'7)@\0D6UW#58GE@>PH(```9:$4````B47T
M,<#'A>S?__\`````Z$;V__^Z0=0$",=$)`Q-U`0(B40D"(E4)`2-A?/O__^)
M!"3H`_;__XF%Z-___X.]Z-___P!Y"K@`````Z90```"-A?/O___'1"0(`!``
M`(V5\M___XE4)`2)!"3H:OG__XF%Z-___X.]Z-___P!Y![@`````ZUZ+A>C?
M__^#P`&)!"3HT_C__XF%[-___X.][-___P!U![@`````ZS>+A>C?__^)1"0(
MC87RW___B40D!(N%[-___XD$).C;]___BX7HW___`X7LW___Q@``BX7LW___
MBU7T93,5%````'0%Z)7X___)PU6)Y8/L".CO_O__R<-5B>6![%@0``"+10B)
MA=3O__^+10R)A=#O__]EH10```")1?0QP,<$)%'4!`CHC/S__XF%Z.___Z%$
M404(B40D!(N%U.___XD$).@'^/__A<!T(8N%U.___XE$)`3'!"1:U`0(Z&_\
M__^+A=3O___I+0(``(N%U.___XD$).A$]___B87D[___H4A1!0B)1"0$BX70
M[___B00DZ`?X__^)A?#O___IS@$``(N%\.___P^V`(3`=0K'A?#O__]GU`0(
M@[WH[___`'0\BX7P[___B40D!(N%Z.___XD$).CD^/__A<!U(*%(404(B40D
M!,<$)`````#HJ_?__XF%\.___^ER`0``BX7P[___B00DZ++V__^)A>SO___K
M%H.M[.___P&+A>SO__\#A?#O___&``"+A>SO__^#Z`$#A?#O__\/MA"A1%$%
M"`^V`#C"=,R+A>SO__^#P`$#A>3O__\]_P\``'XABX74[___B40D!,<$)%K4
M!`CH7/O__XN%U.___^D:`0``BQ5$404(N&G4!`B+C=3O__^)3"00B50D#(N5
M\.___XE4)`B)1"0$C87T[___B00DZ'KS___'!"0`````Z-[W__^+`(D$).C$
M]/__B00DZ.SV__^-E?3O__^)1"0$B10DZ`8R``"%P'5MQP0D`````.BJ]___
MBP")!"3HD/3__XD$).BX]O__BT`0)0#P```]`(```'5`QT0D!`$```"-A?3O
M__^)!"3HT_3__X7`=2:-A?3O__^)1"0$QP0D6M0$".B+^O__C87T[___B00D
MZ#OW___K1*%(404(B40D!,<$)`````#H-/;__XF%\.___X.]\.___P`/A27^
M__^+A=3O__^)1"0$QP0D6M0$".@]^O__BX74[___BU7T93,5%````'0%Z-3U
M___)PU6)Y8/L$(M%"(E%_(M%"(E%^.L?BT7X#[80H411!0@/M@`XPG4)BT7X
M@\`!B47\@T7X`8M%^`^V`(3`==>+1?S)PU6)Y5.#[!2#?0@`=`J+10@/M@"$
MP'41QP0D9]0$".A]]O__Z=,```"+10B)!"3HG?3__X/H`8G#`UT(ZP.#ZP$[
M70AV%`^V$Z%$404(#[8`.,)TZ>L#@^L!.UT(=@\/MA.A1%$%"`^V`#C"=>D[
M70AU+`^V$Z%$404(#[8`.,)U#L<$)&?4!`CH$_;__^MLH411!0B)!"3H!/;_
M_^M=@^L!.UT(=@\/MA.A1%$%"`^V`#C"=.F)VHM%"(G1*<&)R(/``CT`$```
M=@>X`````.LJB=J+10B)T2G!B<B#P`&)1"0(BT4(B40D!,<$)*!1!0CH&O+_
M_[B@404(@\046UW#58GE@^Q(9:$4````B47T,<"A'-4$"(E%TJ$@U00(B476
MH235!`B)1=JA*-4$"(E%WJ$LU00(B47BH3#5!`B)1>:A--4$"(E%ZJ$XU00(
MB47N#[<%/-4$"&:)1?+'!"1PU`0(Z$CZ___'!"2`U`0(Z#SZ___'!"11U`0(
MZ##Z___'!"2,U`0(Z"3Z___'!"26U`0(Z!CZ___'!"2@U`0(Z`SZ___'!"1:
MU`0(Z`#Z___'!"2JU`0(Z/3Y___'!"2SU`0(Z.CY___'!"2^U`0(Z//W__^)
M1<R#?<P`=!.+1<R)1"0$QP0DEM0$".CQ]___QP0DS]0$".C+]___B47,@WW,
M`'03BT7,B40D!,<$).'4!`CHR??__\<$).S4!`CHH_?__XE%S(-]S`!T%8M%
MS(E$)`3'!"11U`0(Z*'W___K:,<$)/S4!`CH>??__XE%S(-]S`!T%8M%S(E$
M)`3'!"2,U`0(Z'?W___K/HU%TH/`$8E%S,=$)`@*````QT0D!`W5!`B+1<R)
M!"3HO_/__X7`=1:+1<R#P`J)1"0$QP0DC-0$".@W]___QT0D!!C5!`C'!"1P
MU`0(Z"/W__^+1?1E,P44````=`7HP/+__\G#58GE@^PHH4Q1!0B#^/]U.L<$
M)(S4!`CHVO;__XE%](-]]`!T&XM%]`^V`(3`=!&+1?0/M@`\,'0'N`$```#K
M!;@`````HTQ1!0BA3%$%",G#58GE4X'L<`$``(M%"(/`'(E%],=%^`````#K
M1(M%](L`B47P@T7T!(M%\(G"P>(8BT7PP>`()0``_P`)PHM%\,'H""4`_P``
M"<*+1?#!Z!@)PHM%^(F4A9C^__^#1?@!@WWX#WZVQT7X$````.M@BT7X@^@#
MBY2%F/[__XM%^(/H"(N$A9C^__\QPHM%^(/H#HN$A9C^__\QPHM%^(/H$(N$
MA9C^__\QPHM%^(F4A9C^__^+1?B+A(68_O__B<+1PHM%^(F4A9C^__^#1?@!
M@WWX3WZ:BT4(BP")1>R+10B+0`2)1>B+10B+0`B)1>2+10B+0`R)1>"+10B+
M0!")1=R-A9C^__^)1=B+1>R)P<'!!8M%Y(M5Z"'"BT7H]]`C1>`)T(T$`8G"
M`U7<BT78BP"-!`(%F7F"6HE%\(-%V`3!1>@>BT7PB<'!P06+1>B+5>PAPHM%
M[/?0(T7D"="-!`&)P@-5X(M%V(L`C00"!9EY@EJ)1=R#1=@$P47L'HM%W(G!
MP<$%BT7LBU7P(<*+1?#WT"-%Z`G0C00!B<(#5>2+1=B+`(T$`@69>8):B47@
M@T78!,%%\!Z+1>")P<'!!8M%\(M5W"'"BT7<]]`C1>P)T(T$`8G"`U7HBT78
MBP"-!`(%F7F"6HE%Y(-%V`3!1=P>BT7DB<'!P06+1=R+5>`APHM%X/?0(T7P
M"="-!`&)P@-5[(M%V(L`C00"!9EY@EJ)1>B#1=@$P47@'HM%Z(G!P<$%BT7@
MBU7D(<*+1>3WT"-%W`G0C00!B<(#5?"+1=B+`(T$`@69>8):B47L@T78!,%%
MY!Z+1>R)P<'!!8M%Y(M5Z"'"BT7H]]`C1>`)T(T$`8G"`U7<BT78BP"-!`(%
MF7F"6HE%\(-%V`3!1>@>BT7PB<'!P06+1>B+5>PAPHM%[/?0(T7D"="-!`&)
MP@-5X(M%V(L`C00"!9EY@EJ)1=R#1=@$P47L'HM%W(G!P<$%BT7LBU7P(<*+
M1?#WT"-%Z`G0C00!B<(#5>2+1=B+`(T$`@69>8):B47@@T78!,%%\!Z+1>")
MP<'!!8M%\(M5W"'"BT7<]]`C1>P)T(T$`8G"`U7HBT78BP"-!`(%F7F"6HE%
MY(-%V`3!1=P>BT7DB<'!P06+1=R+5>`APHM%X/?0(T7P"="-!`&)P@-5[(M%
MV(L`C00"!9EY@EJ)1>B#1=@$P47@'HM%Z(G!P<$%BT7@BU7D(<*+1>3WT"-%
MW`G0C00!B<(#5?"+1=B+`(T$`@69>8):B47L@T78!,%%Y!Z+1>R)P<'!!8M%
MY(M5Z"'"BT7H]]`C1>`)T(T$`8G"`U7<BT78BP"-!`(%F7F"6HE%\(-%V`3!
M1>@>BT7PB<'!P06+1>B+5>PAPHM%[/?0(T7D"="-!`&)P@-5X(M%V(L`C00"
M!9EY@EJ)1=R#1=@$P47L'HM%W(G!P<$%BT7LBU7P(<*+1?#WT"-%Z`G0C00!
MB<(#5>2+1=B+`(T$`@69>8):B47@@T78!,%%\!Z+1>")P<'!!8M%\(M5W"'"
MBT7<]]`C1>P)T(T$`8G"`U7HBT78BP"-!`(%F7F"6HE%Y(-%V`3!1=P>BT7D
MB<'!P06+1=R+5>`APHM%X/?0(T7P"="-!`&)P@-5[(M%V(L`C00"!9EY@EJ)
M1>B#1=@$P47@'HM%Z(G!P<$%BT7@BU7D(<*+1>3WT"-%W`G0C00!B<(#5?"+
M1=B+`(T$`@69>8):B47L@T78!,%%Y!Z+1>R)P<'!!8M%Y(M5Z"'"BT7H]]`C
M1>`)T(T$`8G"`U7<BT78BP"-!`(%F7F"6HE%\(-%V`3!1>@>BT7PB<'!P06+
M1>B+5>PAPHM%[/?0(T7D"="-!`&)P@-5X(M%V(L`C00"!9EY@EJ)1=R#1=@$
MP47L'HM%W(G!P<$%BT7LBU7P,=`S1>B-!`&)P@-5Y(M%V(L`C00"!:'KV6Z)
M1>"#1=@$P47P'HM%X(G!P<$%BT7PBU7<,=`S1>R-!`&)P@-5Z(M%V(L`C00"
M!:'KV6Z)1>2#1=@$P47<'HM%Y(G!P<$%BT7<BU7@,=`S1?"-!`&)P@-5[(M%
MV(L`C00"!:'KV6Z)1>B#1=@$P47@'HM%Z(G!P<$%BT7@BU7D,=`S1=R-!`&)
MP@-5\(M%V(L`C00"!:'KV6Z)1>R#1=@$P47D'HM%[(G!P<$%BT7DBU7H,=`S
M1>"-!`&)P@-5W(M%V(L`C00"!:'KV6Z)1?"#1=@$P47H'HM%\(G!P<$%BT7H
MBU7L,=`S1>2-!`&)P@-5X(M%V(L`C00"!:'KV6Z)1=R#1=@$P47L'HM%W(G!
MP<$%BT7LBU7P,=`S1>B-!`&)P@-5Y(M%V(L`C00"!:'KV6Z)1>"#1=@$P47P
M'HM%X(G!P<$%BT7PBU7<,=`S1>R-!`&)P@-5Z(M%V(L`C00"!:'KV6Z)1>2#
M1=@$P47<'HM%Y(G!P<$%BT7<BU7@,=`S1?"-!`&)P@-5[(M%V(L`C00"!:'K
MV6Z)1>B#1=@$P47@'HM%Z(G!P<$%BT7@BU7D,=`S1=R-!`&)P@-5\(M%V(L`
MC00"!:'KV6Z)1>R#1=@$P47D'HM%[(G!P<$%BT7DBU7H,=`S1>"-!`&)P@-5
MW(M%V(L`C00"!:'KV6Z)1?"#1=@$P47H'HM%\(G!P<$%BT7HBU7L,=`S1>2-
M!`&)P@-5X(M%V(L`C00"!:'KV6Z)1=R#1=@$P47L'HM%W(G!P<$%BT7LBU7P
M,=`S1>B-!`&)P@-5Y(M%V(L`C00"!:'KV6Z)1>"#1=@$P47P'HM%X(G!P<$%
MBT7PBU7<,=`S1>R-!`&)P@-5Z(M%V(L`C00"!:'KV6Z)1>2#1=@$P47<'HM%
MY(G!P<$%BT7<BU7@,=`S1?"-!`&)P@-5[(M%V(L`C00"!:'KV6Z)1>B#1=@$
MP47@'HM%Z(G!P<$%BT7@BU7D,=`S1=R-!`&)P@-5\(M%V(L`C00"!:'KV6Z)
M1>R#1=@$P47D'HM%[(G!P<$%BT7DBU7H,=`S1>"-!`&)P@-5W(M%V(L`C00"
M!:'KV6Z)1?"#1=@$P47H'HM%\(G!P<$%BT7HBU7L,=`S1>2-!`&)P@-5X(M%
MV(L`C00"!:'KV6Z)1=R#1=@$P47L'HM%W(G!P<$%BT7LBU7P,=`S1>B-!`&)
MP@-5Y(M%V(L`C00"!:'KV6Z)1>"#1=@$P47P'HM%X(G!P<$%BT7PBU7<,=`S
M1>R-!`&)P@-5Z(M%V(L`C00"!:'KV6Z)1>2#1=@$P47<'HM%Y(G#P<,%BT7P
MBU7<"=`C1>"+5?"+3=PAR@G0C00#B<(#5>R+1=B+`(T$`BTD0^1PB47H@T78
M!,%%X!Z+1>B)P\'#!8M%W(M5X`G0(T7DBU7<BTW@(<H)T(T$`XG"`U7PBT78
MBP"-!`(M)$/D<(E%[(-%V`3!1>0>BT7LB</!PP6+1>"+5>0)T"-%Z(M5X(M-
MY"'*"="-!`.)P@-5W(M%V(L`C00"+21#Y'")1?"#1=@$P47H'HM%\(G#P<,%
MBT7DBU7H"=`C1>R+5>2+3>@AR@G0C00#B<(#5>"+1=B+`(T$`BTD0^1PB47<
M@T78!,%%[!Z+1=R)P\'#!8M%Z(M5[`G0(T7PBU7HBTWL(<H)T(T$`XG"`U7D
MBT78BP"-!`(M)$/D<(E%X(-%V`3!1?`>BT7@B</!PP6+1>R+5?`)T"-%W(M5
M[(M-\"'*"="-!`.)P@-5Z(M%V(L`C00"+21#Y'")1>2#1=@$P47<'HM%Y(G#
MP<,%BT7PBU7<"=`C1>"+5?"+3=PAR@G0C00#B<(#5>R+1=B+`(T$`BTD0^1P
MB47H@T78!,%%X!Z+1>B)P\'#!8M%W(M5X`G0(T7DBU7<BTW@(<H)T(T$`XG"
M`U7PBT78BP"-!`(M)$/D<(E%[(-%V`3!1>0>BT7LB</!PP6+1>"+5>0)T"-%
MZ(M5X(M-Y"'*"="-!`.)P@-5W(M%V(L`C00"+21#Y'")1?"#1=@$P47H'HM%
M\(G#P<,%BT7DBU7H"=`C1>R+5>2+3>@AR@G0C00#B<(#5>"+1=B+`(T$`BTD
M0^1PB47<@T78!,%%[!Z+1=R)P\'#!8M%Z(M5[`G0(T7PBU7HBTWL(<H)T(T$
M`XG"`U7DBT78BP"-!`(M)$/D<(E%X(-%V`3!1?`>BT7@B</!PP6+1>R+5?`)
MT"-%W(M5[(M-\"'*"="-!`.)P@-5Z(M%V(L`C00"+21#Y'")1>2#1=@$P47<
M'HM%Y(G#P<,%BT7PBU7<"=`C1>"+5?"+3=PAR@G0C00#B<(#5>R+1=B+`(T$
M`BTD0^1PB47H@T78!,%%X!Z+1>B)P\'#!8M%W(M5X`G0(T7DBU7<BTW@(<H)
MT(T$`XG"`U7PBT78BP"-!`(M)$/D<(E%[(-%V`3!1>0>BT7LB</!PP6+1>"+
M5>0)T"-%Z(M5X(M-Y"'*"="-!`.)P@-5W(M%V(L`C00"+21#Y'")1?"#1=@$
MP47H'HM%\(G#P<,%BT7DBU7H"=`C1>R+5>2+3>@AR@G0C00#B<(#5>"+1=B+
M`(T$`BTD0^1PB47<@T78!,%%[!Z+1=R)P\'#!8M%Z(M5[`G0(T7PBU7HBTWL
M(<H)T(T$`XG"`U7DBT78BP"-!`(M)$/D<(E%X(-%V`3!1?`>BT7@B</!PP6+
M1>R+5?`)T"-%W(M5[(M-\"'*"="-!`.)P@-5Z(M%V(L`C00"+21#Y'")1>2#
M1=@$P47<'HM%Y(G#P<,%BT7PBU7<"=`C1>"+5?"+3=PAR@G0C00#B<(#5>R+
M1=B+`(T$`BTD0^1PB47H@T78!,%%X!Z+1>B)P\'#!8M%W(M5X`G0(T7DBU7<
MBTW@(<H)T(T$`XG"`U7PBT78BP"-!`(M)$/D<(E%[(-%V`3!1>0>BT7LB<'!
MP06+1>2+5>@QT#-%X(T$`8G"`U7<BT78BP"-!`(M*CZ=-8E%\(-%V`3!1>@>
MBT7PB<'!P06+1>B+5>PQT#-%Y(T$`8G"`U7@BT78BP"-!`(M*CZ=-8E%W(-%
MV`3!1>P>BT7<B<'!P06+1>R+5?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(M*CZ=
M-8E%X(-%V`3!1?`>BT7@B<'!P06+1?"+5=PQT#-%[(T$`8G"`U7HBT78BP"-
M!`(M*CZ=-8E%Y(-%V`3!1=P>BT7DB<'!P06+1=R+5>`QT#-%\(T$`8G"`U7L
MBT78BP"-!`(M*CZ=-8E%Z(-%V`3!1>`>BT7HB<'!P06+1>"+5>0QT#-%W(T$
M`8G"`U7PBT78BP"-!`(M*CZ=-8E%[(-%V`3!1>0>BT7LB<'!P06+1>2+5>@Q
MT#-%X(T$`8G"`U7<BT78BP"-!`(M*CZ=-8E%\(-%V`3!1>@>BT7PB<'!P06+
M1>B+5>PQT#-%Y(T$`8G"`U7@BT78BP"-!`(M*CZ=-8E%W(-%V`3!1>P>BT7<
MB<'!P06+1>R+5?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(M*CZ=-8E%X(-%V`3!
M1?`>BT7@B<'!P06+1?"+5=PQT#-%[(T$`8G"`U7HBT78BP"-!`(M*CZ=-8E%
MY(-%V`3!1=P>BT7DB<'!P06+1=R+5>`QT#-%\(T$`8G"`U7LBT78BP"-!`(M
M*CZ=-8E%Z(-%V`3!1>`>BT7HB<'!P06+1>"+5>0QT#-%W(T$`8G"`U7PBT78
MBP"-!`(M*CZ=-8E%[(-%V`3!1>0>BT7LB<'!P06+1>2+5>@QT#-%X(T$`8G"
M`U7<BT78BP"-!`(M*CZ=-8E%\(-%V`3!1>@>BT7PB<'!P06+1>B+5>PQT#-%
MY(T$`8G"`U7@BT78BP"-!`(M*CZ=-8E%W(-%V`3!1>P>BT7<B<'!P06+1>R+
M5?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(M*CZ=-8E%X(-%V`3!1?`>BT7@B<'!
MP06+1?"+5=PQT#-%[(T$`8G"`U7HBT78BP"-!`(M*CZ=-8E%Y(-%V`3!1=P>
MBT7DB<'!P06+1=R+5>`QT#-%\(T$`8G"`U7LBT78BP"-!`(M*CZ=-8E%Z(-%
MV`3!1>`>BT7HB<'!P06+1>"+5>0QT#-%W(T$`8G"`U7PBT78BP"-!`(M*CZ=
M-8E%[(-%V`3!1>0>BT7LB<'!P06+1>2+5>@QT#-%X(T$`8G"`U7<BT78BP"-
M!`(M*CZ=-8E%\(-%V`3!1>@>BT7PB<'!P06+1>B+5>PQT#-%Y(T$`8G"`U7@
MBT78BP"-!`(M*CZ=-8E%W(-%V`3!1>P>BT4(BP")P@-5W(M%"(D0BT4(BT`$
MB<(#5?"+10B)4`2+10B+0`B)P@-5[(M%"(E0"(M%"(M`#(G"`U7HBT4(B5`,
MBT4(BT`0B<(#5>2+10B)4!"!Q'`!``!;7<-5B>6+10C'``$C16>+10C'0`2)
MJ\WOBT4(QT`(_MRZF(M%",=`#'94,A"+10C'0!#PX=+#BT4(QT`4`````(M%
M",=`&`````"+10C'0%P`````7<-5B>6#["B+10B+0!2+51#!X@,!T(E%\(M%
M"(M`%#M%\'8/BT4(BT`8C5`!BT4(B5`8BT4(BU7PB5`4BT4(BT`8BU40P>H=
MC100BT4(B5`8BT4(BT!<A<`/A*P```"+10B+0%RZ0````(G1*<&)R(E%](M%
M]#M%$'X&BT40B47TBT7TBU4(C4H<BU4(BU)<C101B40D"(M%#(E$)`2)%"3H
MZ]W__XM%]"E%$(M%]`%%#(M%"(M`7(G"`U7TBT4(B5!<BT4(BT!<@_A`=6J+
M10B)!"3H*^S__^LPBT4(C5`<QT0D"$````"+10R)1"0$B10DZ)G=__^#10Q`
M@VT00(M%"(D$).CYZ___@WT0/W_*BT40BU4(@\(<B40D"(M%#(E$)`2)%"3H
M9-W__XM%"(M5$(E07.L!D,G#58GE@^P$BT4,B00DZ+CK__^+10R+`,'H&(G"
MBT4(B!"+10B-4`&+10R+`,'H$(@"BT4(C5`"BT4,BP#!Z`B(`HM%"(U0`XM%
M#(L`B`*+10B-4`2+10R+0`3!Z!B(`HM%"(U0!8M%#(M`!,'H$(@"BT4(C5`&
MBT4,BT`$P>@(B`*+10B-4`>+10R+0`2(`HM%"(U0"(M%#(M`",'H&(@"BT4(
MC5`)BT4,BT`(P>@0B`*+10B-4`J+10R+0`C!Z`B(`HM%"(U0"XM%#(M`"(@"
MBT4(C5`,BT4,BT`,P>@8B`*+10B-4`V+10R+0`S!Z!"(`HM%"(U0#HM%#(M`
M#,'H"(@"BT4(C5`/BT4,BT`,B`*+10B-4!"+10R+0!#!Z!B(`HM%"(U0$8M%
M#(M`$,'H$(@"BT4(C5`2BT4,BT`0P>@(B`*+10B-4!.+10R+0!"(`LG#58GE
M@^PHBT4,BT`4B47TBT4,BT`8B47PBT7TP>@#@^`_B47LBT4,C5`<BT7LC00"
MQ@"`@T7L`8-][#A^4[A`````*T7LBU4,C4H<BU7LC101B40D",=$)`0`````
MB10DZ%[:__^+10R)!"3H!NK__XM%#(/`',=$)`@X````QT0D!`````")!"3H
M-=K__^LHN#@````K1>R+50R-2AR+5>R-%!&)1"0(QT0D!`````")%"3H"]K_
M_XM%\,'H&(G"BT4,B%!4BT7PP>@0B<*+10R(4%6+1?#!Z`B)PHM%#(A05HM%
M\(G"BT4,B%!7BT7TP>@8B<*+10R(4%B+1?3!Z!")PHM%#(A068M%],'H"(G"
MBT4,B%!:BT7TB<*+10R(4%N+10R)1"0$BT4(B00DZ'G]___)PU6)Y8/L*,=%
M]`````#'1?``````Z!3;__^)!"3H[-K__XE%\(-]\`!T"(M%\(L`B47TBT7T
MR<-5B>6#[!C'!"0`````Z(3<__^+`(D$).AJV?__B00DZ)+;__^)1"0$BT4(
MB00DZ-\6``"%P'5XQP0D`````.A3W/__BP")!"3H.=G__XD$).AAV___BT`0
M)0#P```]`$```'0MQP0D`````.@FW/__BP")!"3H#-G__XD$).@TV___BT`0
M)0#P```]`*```'4>QT0D!`(```"+10B)!"3H4MG__X7`=0>X`0```.L%N```
M``#)PU6)Y5.#[%3'1?``````QT7L`````,=%T#[5!`C'1=1.U00(QT785M4$
M",=%W&/5!`C'1>!HU00(QT7D>M4$",=%Z`````#'1?0`````Z<4```"+1?")
M!"3HF][__XE%[(-][`!T"HM%[`^V`(3`=1>+10B)1"0$BT7PB00DZ)#>___I
MC````(M%"(E$)`2+1>R)!"3H]]G__X7`=7:+10B)!"3H6-G__XG#H4A1!0B)
M!"3H2=G__P'#BT7LB00DZ#S9__^-!`.#P`*)!"3HSMG__XE%Z(L52%$%"+AI
MU`0(BTWLB4PD$(E4)`R+50B)5"0(B40D!(M%Z(D$).AOUO__BT7HB40D!(M%
M\(D$).C_W?__@T7T`8M%](M$A=")1?"+1?`/M@"$P`^%(____X/$5%M=PU6)
MY5.![%2!``"+10B)A=1^__]EH10```")1?0QP,>%2'___P````#'A31___\`
M````QX4P?___`````,>%^'[__WO5!`C'A?Q^__^#U00(QX4`?___9]0$",>%
M!'___WK5!`C'A>!^___AU`0(QX7D?O__B-4$",>%Z'[__X_5!`C'A>Q^__^7
MU00(QX7P?O__G-4$",>%]'[__WK5!`C'A0A___^@U00(QX4,?___I=4$",>%
M$'___WK5!`C'A2Q___^NU00(QX4H?___>M4$",>%1'___P````#'A4!___\`
M````QX4D?___`````,>%('___P````#'!"11U`0(Z+W<__^)A3!___^#O3!_
M__\`="Z+A3!___\/M@"$P'0ABX4P?___B00DZ)O]__^+A3!___^)!"3H7=G_
M_^EW!@``Z);\__^)A4!___^#O4!___\`=6W'A5!___\`````ZSB+A31___^)
M!"3H4MS__XF%,'___X.],'___P!T%(N%,'___XD$).@-V?__B85`?___@X50
M?___`8.]0'___P!U((N%4'___XN$A0A___^)A31___^+A31___\/M@"$P'6?
M@[U`?___`'4,QX5`?___L]4$".M0BX5`?___B85,?___ZS7H7];__XL0BX5,
M?___#[8`#[[``<"-!`(/MP`/M\"#X`B%P'4)BX5,?___Q@!?@X5,?___`8N%
M3'___P^V`(3`=;['A5!___\`````ZTJ+A31___^)!"3H@-O__XF%,'___X.]
M,'___P!T)HN%,'___XD$).BU^___A<!T%(N%,'___XD$).@IV/__B85(?___
M@X50?___`8.]2'___P!U((N%4'___XN$A>!^__^)A31___^+A31___\/M@"$
MP'6-QX50?___`````.LMBX4P?___B00DZ%/[__^%P'04BX4P?___B00DZ,?7
M__^)A4A___^#A5!___\!@[U(?___`'4@BX50?___BX2%^'[__XF%,'___XN%
M,'___P^V`(3`=:J+A4A___^)!"3HL]7__XG#BX4L?___B00DZ*/5__\!PXN%
M0'___XD$).B3U?__`<.+A2A___^)!"3H@]7__XT$`P4`!```B84@?___BX4@
M?___B00DZ`?6__^)A21___^+%411!0BXNM4$"(N-0'___XE,)!2+C2Q___^)
M3"00B50D#(N52'___XE4)`B)1"0$BX4D?___B00DZ)+2___'1"0$[0$``(N%
M)'___XD$).BLTO__QP0D8]4$".CXV?__B84P?___@[TP?___`'0JBX4P?___
MB00DZ+/6__^)PHN%U'[__XL`B50D!(D$).@'W?__B85$?___@[U$?___`'4.
MBX74?O__BP")A41____HK>+__X7`#X5J`@``QT0D!`````"+A41___^)!"3H
M'=;__XF%''___X.]''___P`/A$$"``#'1"0,`@```,=$)`3N____QT0D"/__
M__^+A1Q___^)!"3HM-+__\=$)`@&````C854?___B40D!(N%''___XD$).@4
MT___#[:%5'___X3`#X75````#[:%57___SQ##X7&````#[:%5G___SQ!#X6W
M````#[:%5W___SQ##X6H````#[:%6'___SQ(#X69````#[:%67___SQ%#X6*
M````QT0D#`(```#'1"0$QO___\=$)`C_____BX4<?___B00DZ!32___'1"0(
M*0```(V%5'___XE$)`2+A1Q___^)!"3H=-+__XL51%$%"+C#U00(BXTH?___
MB4PD%(V-5'___XE,)!")5"0,BY4D?___B50D"(E$)`2+A21___^)!"3HQ=#_
M_^D5`@``C854____B00DZ#_T___K(HN%&'___XE$)`B-A51___^)1"0$C854
M____B00DZ&_T___'1"0(`(```(V%5'___XE$)`2+A1Q___^)!"3HWM'__XF%
M&'___X.]&'___P!_KXN%''___XD$).A1T___C854____B40D!(U%X(D$).BI
M]O__QX4\?___`````.LYC47@`X4\?___#[8`#[;0N-+5!`B+C3Q___\!R8U=
MMXT,"XE4)`B)1"0$B0PDZ/[/__^#A3Q___\!@[T\?___$WZ^QD7?`(L51%$%
M"+C#U00(BXTH?___B4PD%(U-MXE,)!")5"0,BY4D?___B50D"(E$)`2+A21_
M__^)!"3HKL___^G^````QX4X?___`````(N%)'___XD$).@ATO__B844?___
MQT0D!!C5!`C'!"2,U`0(Z!G7___HDL___XL-1%$%"+K7U00(BYTH?___B5PD
M%(E$)!")3"0,BX4D?___B40D"(E4)`2+A21___^)!"3H.<___^MABX44?___
MBY4D?___C00"Q@``@X4X?___`>@YS___BPU$404(NN75!`B+G2A___^)7"08
MBYTX?___B5PD%(E$)!")3"0,BX4D?___B40D"(E4)`2+A21___^)!"3HUL[_
M_\=$)`3M`0``BX4D?___B00DZ/#.__^#^/]U$.BFSO__BP"#^!$/A'3___^+
MA21___^)1"0$QP0D4=0$".@WUO__BX4D?___B00DZ!?W__^+A21___^+5?1E
M,Q44````=`7HP-'__X'$5($``%M=PU6)Y5.![(0```#'1?0`````@WT(``^$
M/@$``(M%"`^V`(3`#X0S`0``BT4(B00DZ"/0__^)1?"#??``#X7H````Z1<!
M``"+1>R#P!/'1"0$9]0$"(D$).B;TO__A<`/A,4```"+1>R#P!/'1"0$]M4$
M"(D$).A]TO__A<`/A*<```"+10B)!"3H:M#__XG#BT7L@\`3B00DZ%K0__^-
M!`.#P`*)1>B+1>B)!"3HYM#__XE%](M%[(U0$[CYU00(B50D#(M5"(E4)`B)
M1"0$BT7TB00DZ([-__^+1?2-58B)5"0$B00DZ#@,``"#^/]T'(M%F"4`\```
M/0!```!U#8M%](D$).CV_O__ZPN+1?2)!"3H\,___XM%](D$).CESO__QT7T
M`````(M%\(D$).B3S___B47L@WWL``^%!?___XM%\(D$).@+T/__BT4(B00D
MZ'#0___K!)#K`9"!Q(0```!;7<-5B>6#["B+10B)!"3HL-K__XE%](M%](D$
M).A@VO__B47PZ&S=__^%P'0S@WT(`'0MBT4(#[8`A,!T(\=$)`2NU00(BT7P
MB00DZ-//__\[1?!U"XM%"(D$).@\_O__R<-5B>564X/L$,<$)`````#H_=#_
M_XL`B00DZ./-__^)!"3HB\S__XL`BU@$QP0D`````.C:T/__BP")!"3HP,W_
M_XD$).@(S?__#[8`#[;`B<:#YG_'!"0`````Z+'0__^+`(D$).B7S?__B00D
MZ._,__^+``^W0!!F)?\!#[?`P>`'"?!FB4,"QP0D`````.A]T/__BP")!"3H
M8\W__XD$).@+S/__BP"+6`3'!"0`````Z%K0__^+`(D$).A`S?__QT0D"```
M``#'1"0$>M4$"(D$).BXS___B4,<QP0D`````.@IT/__BP")!"3H#\W__XD$
M).BWR___BP"+6`3'!"0`````Z`;0__^+`(D$).CLS/__B00DZ!3,__^+`(E#
M(,<$)`````#HX\___XL`B00DZ,G,__^)!"3H<<O__XL`BU@$QP0D`````.C`
MS___BP")!"3HILS__XD$).B^SO__BP"%P'0EQP0D`````.B<S___BP")!"3H
M@LS__XD$).B:SO__BP"+0&SK!;@`````B4,DQP0D`````.AOS___BP")!"3H
M5<S__XD$).C]RO__BP"+0`3'0"@`````QP0D`````.A%S___BP")!"3H*\S_
M_XD$).C3RO__BP"+0`3'0!@`````QP0D`````.@;S___BP")!"3H`<S__XD$
M).BIRO__BP"+6`3'!"0`````Z/C.__^+`(D$).C>R___B00DZ*;.__^+`(E#
M+(/$$%M>7<-5B>6#[!C'!"0`````Z,C.__^+`(D$).BNR___QT0D!/____^)
M!"3H[LO__\<$)`````#HHL[__XL`B00DZ(C+___'1"0(`````,=$)`3_QP0(
MB00DZ-#.___)PU6)Y593@^PPQT7P`````,<$)`````#H8\[__XL`B00DZ$G+
M__^)!"3HP<O__\8``<<$)'#4!`CH6M'__XE%[(-][`!T%XM%[`^V`#PQ=0V+
M1>R#P`$/M@"$P'0%Z&[8___'!"0`````Z!'.__^+`(D$).CWRO__QT0D#`L`
M``#'1"0(`0```,=$)`3_U00(B00DZ)?*__^)1>B#?>@`#X0V`0``BT7HBT`,
MBT`8B47DQT7T`0```.F^````BT7TC5C_QP0D`````.BPS?__BP")!"3HELK_
M_\=$)`P`````B5PD"(M5Y(E4)`2)!"3H^\O__XE%X(-]X``/A(H```"+1>"+
M`(M`""4`!```A<!T"HM%X(L`BT`,ZS>+1>"+&,<$)`````#H4LW__XL`B00D
MZ#C*___'1"0,`@```,=$)`@`````B5PD!(D$).B,S?__BQ6,404(BTWTP>$"
M`<J+$HE$)`2)%"3H,,W__X7`=1N#1?`!@T7T`:&(404(.47T#XPT____ZP20
MZP&0H8A1!0B#Z`$[1?!U/\=%]`$```#K+,<$)`````#HSLS__XL`B00DZ+3)
M__^+5>2)5"0$B00DZ%7)__^)1=R#1?0!H8A1!0@Y1?1\RL<$)`````#HF,S_
M_XL`B00DZ'[)___'1"0,!````,=$)`@!````QT0D!`36!`B)!"3H'LG__XE%
MZ(-]Z`!T<(M%Z(M`#(L8QP0D`````.A1S/__BP")!"3H-\G__\=$)`@&U@0(
MB5PD!(D$).@#R?__BT7HBT`,BP"+0`@E``!``(7`="J+1>B+0`R+&,<$)```
M``#H"\S__XL`B00DZ/'(__^)7"0$B00DZ,7*___'!"0`````Z.G+__^+`(D$
M).C/R/__QT0D#`0```#'1"0(`0```,=$)`0+U@0(B00DZ&_(__^)1>B#?>@`
M#X2$````QT78`````,<$)%K4!`CHM\[__XE%V(-]V`!T,XM%Z(M`#(L8QP0D
M`````.B"R___BP")!"3H:,C__XM5V(E4)`B)7"0$B00DZ#7(___K-:&,404(
MBS"+1>B+0`R+&,<$)`````#H2,O__XL`B00DZ"[(__^)="0(B5PD!(D$).AZ
MS/__QP0D`````.@BR___BP")!"3H",C__XD$).B`R/__Q@``QP0D`````.@!
MR___BP")!"3HY\?__XD$).@?R___QP``````QP0D4=0$".CUS?__HX11!0BA
MA%$%"(7`#X4``0``H8Q1!0B)!"3H$_#__Z.$404(BQV,404(BT7HBT`,BP"+
M0`@E``0``(7`=`V+1>B+0`R+`(M`#.LZBT7HBT`,BS#'!"0`````Z'[*__^+
M`(D$).ADQ___QT0D#`(```#'1"0(`````(ET)`2)!"3HN,K__XE<)`2)!"3H
M7,C__XE%](M%Z(M`#(L`BT`()0`$``"%P'0-BT7HBT`,BP"+0`SK.HM%Z(M`
M#(L8QP0D`````.@4RO__BP")!"3H^L;__\=$)`P"````QT0D"`````")7"0$
MB00DZ$[*__^+%8Q1!0B+$HM-](E,)`R)1"0(B50D!,<$)!#6!`CH&\G__Z&$
M404(QT0D!.T!``")!"3H=L7__XE%](-]]`!T-(-]]!%T+H-]]/]T*(L5A%$%
M"*&,404(BP"+3?2)3"0,B50D"(E$)`3'!"1`U@0(Z,G(__^#Q#!;7EW#58GE
M@^PHQP0D`````.A@R?__BP")!"3H1L;__XD$).A6RO__QP0D`````.A"R?__
MBP")!"3H*,;__\=$)!0`````QT0D$'K5!`C'1"0,>M4$",=$)`B2R@0(QT0D
M!([6!`B)!"3HV,;__\G#58GE@^3P@^Q`C440B40D"(U%#(E$)`2-10B)!"3H
MQ,C__\=$)`@`E00(QT0D!`"5!`C'!"30E@0(Z'0"``#'!"0`````Z-S%__\/
MM@"$P'5-Z,#%__^C@%$%"*&`404(A<!U#,<$)`$```#HULC__Z&`404(B00D
MZ&G&___'!"0`````Z'W(__^+`(D$).ACQ?__B00DZ,O'___&``#'!"0`````
MZ%S(__^+`(D$).A"Q?__B00DZ%K(__\/MA"#R@*($,<$)`````#H-LC__XL`
MB00DZ!S%__^)!"3H-,C__P^V$(/*`8@0BT4(@\`%N@````")1"0HB50D+-]L
M)"C9[M[!W06PU@0(V<G?Z=W8#Y?`A,!T%,=$)`1D404(QP0DH]8$".@JQ___
MBT4(@\`%P>`"B00DZ#G'__^CC%$%"*&,404(BU4,BQ*)$*&,404(@\`$QP"F
MU@0(H8Q1!0B#P`C'`.#6!`C'!8A1!0@#````H8Q1!0B+%8A1!0C!X@(!T,<`
MJ=8$"*&(404(@\`!HXA1!0C'1"0X`0```.LLBQ6,404(H8A1!0@#1"0X@^@!
MP>`"`<*+10R+3"0XP>$"`<B+`(D"@T0D.`&+10@Y1"0X?,NAC%$%"(M-"(L5
MB%$%"(T4$8/J`<'B`@'0QP``````BQ6,404(BTT(H8A1!0B-!`&-2/^A@%$%
M",=$)!``````B50D#(E,)`C'1"0$GL\$"(D$).BXPO__B40D/(-\)#P`=1&A
M@%$%"(D$).A0P___B40D/*&`404(B00DZ$_%___'!"2`U`0(Z+O)__^%P'4P
MH811!0B%P'41QP0D4=0$".BBR?__HX11!0BAA%$%"(7`=`VAA%$%"(D$).C^
M]/__H8!1!0B)!"3H,L+__^CMP___BT0D/,G#D)"04X/L$.@Q````@<,O?0``
MBX-,`0``B40D#(M$)"")1"0(BT0D'(E$)`2+1"08B00DZ(_"__^#Q!!;PXL<
M),.0D%575E.#["SH[O___X'#['P``(M\)$"+;"1$Z#7!__^-@_#^__^-D_#^
M__\IT,'X`HE$)!QT(3'VBT0D2(E$)`B);"0$B3PD_Y2S\/[__X/&`3MT)!QR
MX8/$+%M>7UW#PU.#[`SHD?___X'#CWP``(M$)!B)1"0(BT0D%(E$)`3'!"0#
M````Z+G!__^#Q`Q;PU.#[`SH8?___X'#7WP``(M$)!B)1"0(BT0D%(E$)`3'
M!"0#````Z*G"__^#Q`Q;PU6)Y5.#[`2AY$X%"(/X_W01N^1.!0C_T(/K!(L#
M@_C_=?2#Q`1;7<-5B>53@^P$Z`````!;@<,$?```Z*C%__]96\G#`P````$`
M`@!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`"]P<F]C
M+W-E;&8O97AE`"\`.@`O<')O8R\E:2\E<P!E>&4`4$%27U1%35``4$%27U!2
M3T=.04U%`"X`)7,E<R5S`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!0
M05)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P!005)?05)'
M5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-
M4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%
M04X]`#$```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```3$1?
M3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0051(`%!!5$@`1%E,1%],
M24)205)97U!!5$@``$,Z7%1%35``+W1M<`!435!$25(`5$5-4$1)4@!414U0
M`%1-4`!54T52`%5315).04U%`'!A<BT`4UE35$5-`"5S)7,E<R5S`"5S)7-C
M86-H92TE<R5S`"4P,G@`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S
M`"XN`"5S+R5S`$%21U8`&`!P97)L`#``````)7,Z(&5X96-U=&EO;B!O9B`E
M<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A
M8F]R=&EN9R!W:71H("5I+@H`26YT97)N86QS.CI005(Z.D)/3U0`)7,`+64`
M+2T`````````@/___\]!``````````!P87(N<&P`````````````````````
M`````````````",A+W5S<B]B:6XO<&5R;`H*979A;"`G97AE8R`O=7-R+V)I
M;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN
M:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM
M+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M
M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3D*"FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C
M.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R
M7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M
M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER
M("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E
M('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA
M="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@
M)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E
M;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@
M5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS
M('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB
M<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN
M:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S
M;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C
M97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B
M96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME
M(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T
M;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD
M)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@
M("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT
M(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD
M("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L
M965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^
M9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M
M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N
M("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@
M("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B
M86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@
M("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B![
M"B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I
M.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!
M4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B
M?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM0
M05)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@
M("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*
M?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G
M;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@
M<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL
M"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE
M8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H
M)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S
M=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D
M<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D
M8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@
M("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@
M("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R
M96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I
M;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL
M92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ
M<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H
M)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M
M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*
M("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO
M9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@
M("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM
M;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M
M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T
M96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!
M4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,
M24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@
M)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E
M*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@
M("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@
M("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@
M("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C
M(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*
M("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B
M=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B
M('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@
M(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@
M;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@
M?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E
M86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE
M>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME
M>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@
M("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!
M4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@
M("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@
M)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I
M;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H
M+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?
M=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@
M("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*
M("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*
M("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@
M("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D
M9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*
M("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I
M;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER
M92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I
M<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO
M=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI
M;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T
M:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[
M)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@
M("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O
M(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE
M;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E
M("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T
M;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG
M('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D
M(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB
M7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U
M;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@
M('9E<FEF>5]P87(*("`@("D["@H@("`@;7D@0&%D9%]T;U]I;F,["B`@("!W
M:&EL92`H0$%21U8I('L*("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"
M3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("!I9B`H)#$@97$@
M)TDG*2!["B`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@
M(&5V86P@(G5S92`D,B(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E
M<2`G02<I('L*("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@
M("`@("1O=70@/2`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q
M("=B)RD@>PH@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("1B
M=6YD;&4@/2`G86QL)SL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q
M("=Q)RD@>PH@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@(&]P96X@)&QO
M9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D
M(2(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@
M("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("!]"@H@("`@("`@
M('-H:69T*$!!4D=6*3L*"B`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C
M;61[)#%]*2!["B`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PH@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("!R97%U:7)E
M(%!!4CHZ1&ES=#L*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@(&5X:70["B`@("`@("`@
M?0H@("`@?0H*("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*"B,@
M6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T
M<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*
M("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D
M7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@
M("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I
M;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R
M(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@
M("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@
M97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@
M("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@
M("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]
M"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[
M>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2![
M"B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R
M(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES
M(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B
M.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z
M.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z
M.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@
M)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T
M85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L
M(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N
M97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K
M97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME
M>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI
M?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H
M*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@
M)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]
M?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B
M=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?
M:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M
M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE
M;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!
M3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G
M<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@
M:68@*"1#;VYF:6=[7V1E;&EM?2!E<2`G7%PG*2![('-[7%Q]>R]]9R!F;W(@
M0&EN8R!]"@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F
M:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E
M;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI
M="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET:"!N
M;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M96)O
M9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN
M9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N("TM(%-T
M969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A
M;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@
M("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@
M;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL
M97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@
M("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@
M(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@
M("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@
M("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@
M("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@
M("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:
M(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ
M2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@
M("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N
M;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E
M9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@
M("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C
M:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@
M("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@
M("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE
M*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@
M("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N
M("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@
M("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@
M("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@
M("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("`C
M($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O+RH@9G)O;2!E;G9I
M<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@/7X@<R]G;W1O("MR
M971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@("`@("`@("`@("`@
M("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R+G!M(BD["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA
M;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@
M("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@
M("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*
M("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA
M9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I
M('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@
M("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@
M86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T
M>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F
M:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@
M/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?
M;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@
M("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<
M;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@
M("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA
M;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@
M9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@
M("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2
M.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER
M92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@
M("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@
M('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@
M("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@
M;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@
M("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@
M("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@
M("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@
M("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@
M("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@
M("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@
M("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@
M268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY
M("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@
M<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A
M=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET
M:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@
M("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E
M<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E
M($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%
M<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I
M;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E
M(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/
M.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#
M;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@
M<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U
M:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I
M;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@
M4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?
M<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M
M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY
M("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)
M4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<
M7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E
M9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@
M("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@
M9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@
M:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@
M("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@
M("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D
M=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA
M;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H
M)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@
M)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@
M("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@
M("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F
M:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@
M("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@
M("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@
M("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R
M;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@
M("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T
M.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N
M86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X
M(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S
M92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C
M<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE
M;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F
M:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@
M("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA
M;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G
M/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@
M("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E
M<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E
M=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@
M("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P
M.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE
M+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@
M,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I
M('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@
M("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@
M("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD
M("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1
M)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@
M;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@
M("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA
M;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N
M86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@
M(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@
M*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@
M("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R
M;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W
M9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N
M.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$
M14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@
M(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%2
M7R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N
M(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I
M9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?
M0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R
M7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM0
M05)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI
M+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*
M("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB
M.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@
M?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C
M:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC
M(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA
M9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N
M<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U
M8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA
M;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?
M7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)2
M3U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#`R"@I?7T5.1%]?"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/__
M__\`````_____P```````````0````$````!````M`(```$```"_`@```0``
M`,D"```!````&`,```$```!+!```#P```'$$```,````4)0$"`T```#DTP0(
M]?[_;ZR!!`@%````-(H$"`8````$@P0("@```!8&```+````$````!4`````
M`````P```/1/!0@"````>`(``!0````1````%P```-B1!`@1````P)$$"!(`
M```8````$P````@```#^__]O,)$$"/___V\"````\/__;TJ0!`@`````````
M````````````````````````````````````````````````````````````
M^$X%"```````````EI0$"*:4!`BVE`0(QI0$"-:4!`CFE`0(]I0$"`:5!`@6
ME00()I4$"#:5!`A&E00(5I4$"&:5!`AVE00(AI4$"):5!`BFE00(MI4$",:5
M!`C6E00(YI4$"/:5!`@&E@0(%I8$"":6!`@VE@0(1I8$"%:6!`AFE@0(=I8$
M"(:6!`B6E@0(II8$"+:6!`C&E@0(UI8$".:6!`CVE@0(!I<$"!:7!`@FEP0(
M-I<$"$:7!`A6EP0(9I<$"':7!`B&EP0(EI<$"*:7!`BVEP0(QI<$"-:7!`CF
MEP0(]I<$"`:8!`@6F`0()I@$"#:8!`A&F`0(5I@$"&:8!`AVF`0(AI@$"):8
M!`BFF`0(MI@$",:8!`C6F`0(YI@$"/:8!`@&F00(%ID$"":9!`@VF00(1ID$
M"%:9!`AFF00(=ID$"```````````/=0$"#_4!`C_____P-8$"&U9``!'0T,Z
M("A03$0M3&EN=7@I(#0N-2XP(#(P,3`P-3(S("AR96QE87-E*0!'0T,Z("A0
M3$0M3&EN=7@I(#0N-2XP(#(P,3`P-C`Q("AR96QE87-E*0``````'`````(`
M``````0``````("9!`@B```````````````A`````@!V````C0```'4```!?
M24]?<W1D:6Y?=7-E9```````<@````(```````0!`````("9!`BBF00(+BXO
M<WES9&5P<R]I,S@V+V5L9B]S=&%R="Y3`"]H;VUE+W5S97)S+V)U:6QD97(O
M<G!M+T)524Q$+V=L:6)C+3(N,3(O8W-U`$=.52!!4R`R+C(P+C4Q+C`N.``!
M@(D````"`!0````$`0`````!G0```#P```"DF00(I)D$"%L````"`0B/````
M`@(''P````($!X(````"!`=]`````@$&D0````("!3(````#!`5I;G0``@@%
MI`````((!W@````"!`6I````!`0'`@$&F`````5I`````1F'`````04#!-0$
M"`9/``````$1`!`&$0$2`0,(&P@E"!,%`````1$!)0X3"P,.&PX1`1(!$`8`
M``(D``L+/@L##@```R0`"PL^"P,(```$)``+"SX+```%-``##CH+.PM)$S\,
M`@H```8F`$D3````5P````(`,@````$!^PX-``$!`0$````!```!+BXO<WES
M9&5P<R]I,S@V+V5L9@``<W1A<G0N4P`!``````4"@)D$"`/```$S(30])2(#
M&"!96B$B7%L"`0`!`2,````"`!T````!`?L.#0`!`0$!`````0```0!I;FET
M+F,``````$=.52!#(#0N-2XP(#(P,3`P-3(S("AR96QE87-E*0!S:&]R="!U
M;G-I9VYE9"!I;G0`<VAO<G0@:6YT`"]H;VUE+W5S97)S+V)U:6QD97(O<G!M
M+T)524Q$+V=L:6)C+3(N,3(O8W-U`%])3U]S=&1I;E]U<V5D`&QO;F<@;&]N
M9R!U;G-I9VYE9"!I;G0`=6YS:6=N960@8VAA<@!I;FET+F,`;&]N9R!L;VYG
M(&EN=``.`````@!V````C0``````````+G-Y;71A8@`N<W1R=&%B`"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI
M8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`+F1E8G5G7V%R
M86YG97,`+F1E8G5G7W!U8FYA;65S`"YD96)U9U]I;F9O`"YD96)U9U]A8F)R
M978`+F1E8G5G7VQI;F4`+F1E8G5G7W-T<@`N9&5B=6=?<'5B='EP97,`````
M```````````````````````````````````````````````````;`````0``
M``(```!4@00(5`$``!,```````````````$`````````(P````<````"````
M:($$"&@!```@```````````````$`````````#$````'`````@```(B!!`B(
M`0``)```````````````!`````````!$````]O__;P(```"L@00(K`$``%@!
M```%``````````0````$````3@````L````"````!(,$"`0#```P!P``!@``
M``$````$````$````%8````#`````@```#2*!`@T"@``%@8`````````````
M`0````````!>````____;P(```!*D`0(2A```.8````%``````````(````"
M````:P```/[__V\"````,)$$"#`1``"0````!@````(````$`````````'H`
M```)`````@```,"1!`C`$0``&`````4`````````!`````@```"#````"0``
M``(```#8D00(V!$``'@"```%````#`````0````(````C`````$````&````
M4)0$"%`4```P```````````````$`````````(<````!````!@```("4!`B`
M%`````4`````````````!`````0```"2`````0````8```"`F00(@!D``&0Z
M``````````````0`````````F`````$````&````Y-,$".13```<````````
M```````$`````````)X````!`````@````#4!`@`5```3EP`````````````
M(`````````"F`````0````(```!0,`4(4+````0```````````````0`````
M````L`````$````#````Y$X%".2^```(```````````````$`````````+<`
M```!`````P```.Q.!0CLO@``"```````````````!`````````"^`````0``
M``,```#T3@4(]+X```0```````````````0`````````PP````8````#````
M^$X%"/B^``#X````!@`````````$````"````,P````!`````P```/!/!0CP
MOP``!```````````````!`````0```#1`````0````,```#T3P4(]+\``$@!
M``````````````0````$````V@````$````#````/%$%"#S!```<````````
M```````$`````````.`````(`````P```&!1!0A8P0``1!``````````````
M(`````````#E`````0```#``````````6,$``%0```````````````$````!
M````[@````$``````````````+#!```@```````````````(`````````/T`
M```!``````````````#0P0``)0```````````````0`````````-`0```0``
M````````````]<$```,!``````````````$`````````&0$```$`````````
M`````/C"``!?```````````````!`````````"<!```!``````````````!7
MPP``@@```````````````0`````````S`0```0```#``````````V<,``+(`
M``````````````$````!````/@$```$``````````````(O$```2````````
M```````!`````````!$````#``````````````"=Q```3@$`````````````
M`0`````````!`````@``````````````C,L``&`,```C````50````0````0
M````"0````,``````````````.S7``#^"0`````````````!````````````
M````````````````````````5($$"``````#``$``````&B!!`@``````P`"
M``````"(@00(``````,``P``````K($$"``````#``0```````2#!`@`````
M`P`%```````TB@0(``````,`!@``````2I`$"``````#``<``````#"1!`@`
M`````P`(``````#`D00(``````,`"0``````V)$$"``````#``H``````%"4
M!`@``````P`+``````"`E`0(``````,`#```````@)D$"``````#``T`````
M`.33!`@``````P`.````````U`0(``````,`#P``````4#`%"``````#`!``
M`````.1.!0@``````P`1``````#L3@4(``````,`$@``````]$X%"``````#
M`!,``````/A.!0@``````P`4``````#P3P4(``````,`%0``````]$\%"```
M```#`!8``````#Q1!0@``````P`7``````!@404(``````,`&```````````
M```````#`!D``````````````````P`:``````````````````,`&P``````
M```````````#`!P``````````````````P`=``````````````````,`'@``
M```````````````#`!\``````````````````P`@``$```````````````0`
M\?\(```````````````$`/'_$P``````````````!`#Q_QX```#D3@4(````
M``$`$0`L````[$X%"``````!`!(`.@```/1.!0@``````0`3`$<```"DF00(
M``````(`#0!=````>%$%"`$````!`!@`;````'Q1!0@$`````0`8`'H```#S
MF00(``````(`#0`3```````````````$`/'_A@```.A.!0@``````0`1`),`
M``!0,`4(``````$`$`"A````]$X%"``````!`!,`K0```+S3!`@``````@`-
M``@```````````````0`\?_#```````````````$`/'_R@```(!1!0@$````
M`0`8`-(```"$404(!`````$`&`#:````B%$%"`0````!`!@`Z````(Q1!0@$
M`````0`8`/$```!<F@0(*`$```(`#0```0``1%$%"`0````!`!<`"`$``$A1
M!0@$`````0`7`!$!``"$FP0(I`````(`#0`;`0``*)P$"!H````"``T`)@$`
M`$*<!`C/`0```@`-`#$!``"@804(!`````$`&``_`0``$9X$"$8````"``T`
M3`$``*!1!0@`$````0`8`%@!``!,404(!`````$`%P!A`0``@Z4$"*H2```"
M``T`;P$``"VX!`A4`````@`-`'@!``"!N`0(.0$```(`#0"#`0``NKD$"%,!
M```"``T`F@$```V[!`@V`0```@`-`*0!``!ZO`0(M@````(`#0"R`0``.<8$
M"&8!```"``T`OP$``/_'!`@W`@```@`-`,X!``">SP0(;`````(`#0#:`0``
M```````````$`/'_Y@$``+S2!`@Z`````@`-`/<!``#T3P4(``````$`%@`-
M`@``7-,$"#`````"``T`%`(``(S3!`@P`````@`-`!P"``!`404(``````$`
M%P`I`@``\$X%"``````!`!(`-@(``+S2!`@Z`````@`-`$4"``#D3@4(````
M````$0!6`@``Y$X%"````````!$`:0(``/;2!`@``````@`-`(`"``#X3@4(
M``````$`%`")`@``/%$%"``````@`!<`E`(`````````````$@```+`"``!=
MGP0(#0```!(`#0#!`@`````````````2````U`(``!ZB!`A"````$@`-`.$"
M`````````````!(```#X`@`````````````2````"@,`````````````$@``
M`!L#`````````````!(````E`P``6],$"`$````2``T`-0,``("9!`@`````
M$@`-`#P#`````````````!(```!'`P```)4$"``````2````6@,`````````
M````(````&D#`````````````"````!]`P```-0$"`0````1``\`A`,`````
M````````$@```)<#`````````````!(```"K`P`````````````2````P`,`
M````````````$@```-(#`````````````!(```#?`P``Y-,$"``````2``X`
MY0,``)+*!`@,!0``$@`-`/L#`````````````!(````.!``````````````2
M````+00``#*E!`A1````$@`-`#L$``!7G@0(!@$``!(`#0!1!```````````
M```2````9`0`````````````$@```&T$`````````````!(```![!```````
M```````2````BP0`````````````$@```)T$``!@H@0(`0$``!(`#0"I!```
M0[P$"#<````2``T`Q`0`````````````$@```-($``"?QP0(8````!(`#0#>
M!``````````````2````^P0`````````````$@```!H%`````````````!(`
M```J!0``5%$%"`0````1`!<`.04`````````````$@```$0%``#@U@0(;ED`
M`!$`#P!.!0``!-0$"`0````1``\`704`````````````$@```'$%````````
M`````!(```"!!0`````````````2````CP4`````````````$@```*4%````
M`````````!(```"W!0``/%$%"``````0`!<`Q`4`````````````$@```-8%
M`````````````!(```#I!0`````````````2````]P4`````````````$@``
M`!`&``#`E@0(`````!(````@!@``T)8$"``````2````,08`````````````
M$@```$(&`````````````!(```!1!@`````````````2````9@8`````````
M````$@```'@&`````````````!(```"*!@`````````````2````G`8`````
M````````$@```*X&`````````````!(```#"!@``&)H$"$0````2``T`R@8`
M````````````$@```-D&``#\T@0(7P```!(`#0#I!@`````````````2````
M^P8``&!1!0@$````(0`8``X'`````````````!(````<!P`````````````2
M````,`<`````````````$@```$$'`````````````!(```!/!P``````````
M```2````80<``%A1!0@`````$`#Q_VT'`````````````!(```!_!P``````
M```````2````BP<`````````````$@```*<'`````````````!(```"X!P``
M```````````2````R@<`````````````$@```-L'`````````````!(```#M
M!P`````````````2`````0@`````````````$@```!0(```VR@0(7````!(`
M#0`P"``````````````2````10@`````````````$@```&,(``"D804(````
M`!``\?]H"``````````````2````>P@`````````````$@```(@(``!0404(
M!````!$`%P"7"```8%$%"`0````1`!@`K`@`````````````$@```+X(````
M`````````!(```#1"``````````````2````XP@`````````````$@```/4(
M``!D404($P```!$`&``$"0``9;X$"-0'```2``T`$0D``%A1!0@`````$`#Q
M_Q@)`````````````!(````C"0``,+T$"#4!```2``T`-0D``&J?!`BT`@``
M$@`-`$()`````````````!(```!1"0`````````````2````8PD`````````
M````$@```'4)`````````````!(```"*"0`````````````2````G`D`````
M````````$@```*T)`````````````!(```"]"0``8:,$"-$!```2``T`R@D`
M``K0!`BO`@``$@`-`,\)``!0E`0(`````!(`"P#5"0`````````````2````
M[`D`````````````$@````!I;FET+F,`:6YI=&9I;FDN8P!C<G1S='5F9BYC
M`%]?0U1/4E],25-47U\`7U]$5$]27TQ)4U1?7P!?7TI#4E],25-47U\`7U]D
M;U]G;&]B86Q?9'1O<G-?875X`&-O;7!L971E9"XU-3(R`&1T;W)?:61X+C4U
M,C0`9G)A;65?9'5M;7D`7U]#5$]27T5.1%]?`%]?1E)!345?14Y$7U\`7U]*
M0U)?14Y$7U\`7U]D;U]G;&]B86Q?8W1O<G-?875X`&UA:6XN8P!M>5]P97)L
M`'-T;7!D:7(`;W!T:6]N<U]C;W5N=`!F86ME87)G=@!37W!R;V-S96QF7W9A
M;`!D:7)?<V5P`'!A=&A?<V5P`%]?9FEN9&5N=@!P87)?9V5T96YV`'!A<E]S
M971E;G8`86QL;V-E9"XQ-#4T-0!P87)?=6YS971E;G8`8FYA;64N,30V,34`
M<G8N,30V,S$`<VAA7W1R86YS9F]R;0!S:&%?:6YI=`!S:&%?=7!D871E`'-H
M85]T<F%N<V9O<FU?86YD7V-O<'D`<VAA7V9I;F%L`&ES5W)I=&%B;&5$:7(`
M<&%R7W)M=&UP9&ER`'!A<E]R961O7W-T86-K`'!A<E]X<U]I;FET`&UY7W!A
M<E]P;"YC`%]?<'1H<F5A9%]A=&9O<FL`7T=,3T)!3%]/1D93151?5$%"3$5?
M`'-T870V-`!L<W1A=#8T`%]?9'-O7VAA;F1L90!?7T143U)?14Y$7U\`<'1H
M<F5A9%]A=&9O<FL`7U]I;FET7V%R<F%Y7V5N9`!?7VEN:71?87)R87E?<W1A
M<G0`7U]I-C@V+F=E=%]P8U]T:'5N:RYB>`!?1%E.04U)0P!D871A7W-T87)T
M`%]?97)R;F]?;&]C871I;VY`0$=,24)#7S(N,`!P87)?8W5R<F5N=%]E>&5C
M`'-P<FEN=&9`0$=,24)#7S(N,`!P87)?8F%S96YA;64`4&5R;%])8W5R<W1A
M8VMI;F9O7W!T<@!G971P:61`0$=,24)#7S(N,`!M:V1I<D!`1TQ)0D-?,BXP
M`'!E<FQ?9G)E90!?7VQI8F-?8W-U7V9I;FD`7W-T87)T`'!E<FQ?<&%R<V4`
M4&5R;%]A=&9O<FM?=6YL;V-K`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E
M<D-L87-S97,`7V9P7VAW`')E86QL;V-`0$=,24)#7S(N,`!097)L7TEE=F%L
M7W)O;W1?<'1R`%]?>'-T870V-$!`1TQ)0D-?,BXR`%!E<FQ?26EN7V5V86Q?
M<'1R`%!E<FQ?26]P7W!T<@!?9FEN:0!84U]);G1E<FYA;'-?4$%27T)/3U0`
M<W1R;F-P>4!`1TQ)0D-?,BXP`%]?<F5G:7-T97)?871F;W)K0$!'3$E"0U\R
M+C,N,@!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!L<V5E
M:S8T0$!'3$E"0U\R+C(`<&5R;%]R=6X`4&5R;%]A=E]S:&EF=`!097)L7V=V
M7V9E=&-H<'8`;65M<V5T0$!'3$E"0U\R+C``<&%R7V1I<FYA;64`9V5T7W5S
M97)N86UE7V9R;VU?9V5T<'=U:60`4&5R;%]S=E]S971P=@!P87)?8VQE86YU
M<`!?7VQI8F-?<W1A<G1?;6%I;D!`1TQ)0D-?,BXP`'!T:')E861?9V5T<W!E
M8VEF:6-`0$=,24)#7S(N,`!R96%D0$!'3$E"0U\R+C``<VEZ95]L;V%D7VUE
M7S(`<&5R;%]A;&QO8P!L;V%D7VUE7S(`7TE/7W-T9&EN7W5S960`4&5R;%]'
M9&]?=6YD=6UP7W!T<@!F<F5E0$!'3$E"0U\R+C``4&5R;%]D;W5N=VEN9`!?
M7VQX<W1A=#8T0$!'3$E"0U\R+C(`86-C97-S0$!'3$E"0U\R+C``7U]D871A
M7W-T87)T`%!E<FQ?271A:6YT961?<'1R`&]P96YD:7)`0$=,24)#7S(N,`!0
M97)L7W-Y<U]T97)M`%]?8W1Y<&5?8E]L;V-`0$=,24)#7S(N,P!B;V]T7T1Y
M;F%,;V%D97(`4&5R;%]A=&9O<FM?;&]C:P!097)L7VYE=UA37V9L86=S`'!E
M<FQ?8V]N<W1R=6-T`')E861D:7(V-$!`1TQ)0D-?,BXR`&UE;6-P>4!`1TQ)
M0D-?,BXP`&5X96-V<$!`1TQ)0D-?,BXP`'-T<FQE;D!`1TQ)0D-?,BXP`'5N
M;&EN:T!`1TQ)0D-?,BXP`&=E='!W=6ED0$!'3$E"0U\R+C``>'-?:6YI=`!0
M97)L7W-V7W-E='!V;@!?7VQI8F-?8W-U7VEN:70`9V5T=6ED0$!'3$E"0U\R
M+C``96YV:7)O;D!`1TQ)0D-?,BXP`%!E<FQ?879?9F5T8V@`8VQO<V5D:7)`
M0$=,24)#7S(N,`!C;&]S94!`1TQ)0D-?,BXP`'!E<FQ?9&5S=')U8W0`<W1R
M<W1R0$!'3$E"0U\R+C``7U]B<W-?<W1A<G0`;6%L;&]C0$!'3$E"0U\R+C``
M4&5R;%]M9U]S970`7U]S=&%C:U]C:&M?9F%I;$!`1TQ)0D-?,BXT`')M9&ER
M0$!'3$E"0U\R+C``<W1R=&]K0$!'3$E"0U\R+C``4&5R;%])<&%R<V5R7W!T
M<@!097)L7TES=&%T8G5F7W!T<@!R96%D;&EN:T!`1TQ)0D-?,BXP`&UE;6UO
M=F5`0$=,24)#7S(N,`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P
M='(`7V5N9`!097)L7W-A9F5S>7-M86QL;V,`4&5R;%]N97=35G!V`&YA;65?
M;&]A9%]M95\R`%]?96YV:7)O;D!`1TQ)0D-?,BXP`&UE;6-H<D!`1TQ)0D-?
M,BXP`'-T<FYC;7!`0$=,24)#7S(N,`!O<&5N-C1`0$=,24)#7S(N,@!097)L
M7TET;W!?96YV7W!T<@!03%]M96UO<GE?=W)A<`!P87)?;6MT;7!D:7(`7V5D
M871A`%!E<FQ?;F5W6%,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G
M`%!E<FQ?<WES7VEN:70S`'-T<F1U<$!`1TQ)0D-?,BXP`%!E<FQ?1W1H<E]K
M97E?<'1R`%!E<FQ?265X:71?9FQA9W-?<'1R`'-T<F-M<$!`1TQ)0D-?,BXP
M`%!E<FQ?26-O;7!C=E]P='(`97AI=$!`1TQ)0D-?,BXP`'!A<E]I;FET7V5N
M=@!M86EN`%]I;FET`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%]S=E\R
)<'9?9FQA9W,`
